#direct_percent
def percent(n,npercent):
    percentage = npercent/100*n
    return percentage

def min_percent(n,npercent):
    percentage = npercent/100*n
    percentage = n-percentage
    return percentage

def plus_percent(n,npercent):
    percentage = npercent/100*n
    percentage = n+percentage
    return percentage

def x_percent(n,npercent):
    percentage = npercent/100*n
    percentage = n*percentage
    return percentage

def div_percent(n,npercent):
    percentage = npercent/100*n
    percentage = n/percentage
    return percentage

#inverted_percent
def inv_percent(vp,percent):
    percentage = (100*vp)/percent
    return percentage

def min_inv_percent(vp,percent):
    percentage = (100*vp)/percent
    percentage = percentage-vp
    return percentage

def plus_inv_percent(vp,percent):
    percentage = (100*vp)/percent
    percentage = percentage+vp
    return percentage

def x_inv_percent(vp,percent):
    percentage = (100*vp)/percent
    percentage = percentage*vp
    return percentage

def div_inv_percent(vp,percent):
    percentage = (100*vp)/percent
    percentage = percentage/vp
    return percentage

#percentage_between_two_numbers
def compared_percent(n,n1):
    percentage = (100*n)/n1
    return percentage


from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='simplepercent',
  version='0.1',
  description='a simplification to carry out operations with the percentage',
  url='',  
  author='Messana Benedetto',
  author_email='benedettomessana@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='calculator', 
  packages=find_packages(),
  install_requires=[''] 
)
